<?php
/*
 Plugin Name: Dolphin Administrator Panel Example
 Plugin URI: http://another.maple4ever.net/
 Description: Dolphin Administrator Panel Example
 Version: 1.0.0
 Author: hiromasa
 Author URI: http://another.maple4ever.net/
 */

/*  Copyright hiromasa  (email : h1romas4@gmail.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

/******************************************************************************
 * DolphinExample - WordPress Interface Define
 *****************************************************************************/

if(defined('WP_INSTALLING') && WP_INSTALLING) return;
if(!(defined('ABSPATH') && defined('WPINC'))) return;

require_once('dolphin-panel.php');

/******************************************************************************
 * DolphinExample
 *
 * @author      hiromasa
 * @version     1.0.0
 *
 *****************************************************************************/
class DolphinExample implements Dolphinable {
    
    // メンバ変数に設定項目を保持する変数を記述します。
    // 変数の型はバインドされたフォームコンポーネントにより決定します。
    // タイプを配列で設定した場合は同名のフォーム項目を出力順に格納します。
    var $enabled;
    var $header;
    var $footer = array();
    
    /**
     * コンストラクタ内でフィールドの初期化処理を行います。
     * この値がプラグイン管理画面のデフォルト値になります。
     *
     * @return DolphinExample
     */
    function __construct() {
        
        $this->enabled = true;
        $this->header = "ヘッダー1";
        $this->footer[0] = "フッター1";
        $this->footer[1] = "フッター2";
        
    }
    
    /**
     * フィールドを使って普通にプラグインをかきます。
     *
     * @param $content
     * @return $content
     */
    function addContent($content) {
        
        // 有効化チェックがされていなければ何もしない。
        if(!$this->enabled) return $content;
        // content の上に追加（単数）
        $content = "<p>{$this->header}</p>\n" . $content;
        // content の下に追加（配列）
        foreach($this->footer as $foot) {
            $content .= "<p>$foot</p>";
        }
        return $content;
        
    }
    
    /**
     * フォームに対してコントロールの形とフィールド名称を記述しバインドします。
     *
     * @see Dolphinable#onActive($form)
     */
    function onActive(DolphinForm $form) {
        
        // タイトルの設定
        $form->setTitle('DolphinExample');
        // ひとつのチェックボックス
        $form->add(new DolphinCheckBox('$enabled', '有効化'));
        // ひとつのテキストボックス
        $form->add(new DolphinTextBox('$header', 'ヘッダ'));
        // 配列で扱いたい複数のテキストボックス
        $form->add(new DolphinTextBox('$footer', 'フッタ'));
        
    }
    
    /**
     * 値検査を実装し問題なければ true を返却します。
     * また必要ならフォームに対してユーザ対話を設定します。
     *
     * @see Dolphinable#onBind($form)
     */
    function onBind(DolphinForm $form) {
        
        $valid = true;
        // ヘッダーのバリデーション
        if($this->header == '') {
            $form->addMessage("ヘッダーを指定してください。");
            $valid = false;
        }
        // フッターのバリデーション
        $values = '';
        foreach($this->footer as $value) {
            $values .= $value;
        }
        if($values == '') {
            $form->addMessage("フッターのどちらかを指定してください。");
            $valid = false;
        }
        // 正常
        if($valid == true) {
            $form->addMessage("保存しました。");
        } else {
            $form->addMessage("エラーがあったので値の保存を中止しました。");
        }
        return $valid;
        
    }
    
    /**
     * プラグインが Deactivate された時に呼び出されます。
     * データベースの削除が必要であれば remove_dolphin します。
     *
     * @see Dolphinable#onDispose()
     */
    function onDispose() {
        
        remove_dolphin('DolphinExample');
        
    }
    
}

/******************************************************************************
 * DolphinExample - WordPress Interface Define
 *****************************************************************************/

// プラグインのサービスクラスを作成します。
$dolphinExample = new DolphinExample();
// サービスクラスのインスタンスを add_dolphin します。
// 第2引数はこのインスタンスとデータベースを識別するインデックス名です。
add_dolphin($dolphinExample, 'DolphinExample');
// 通常の WordPress と同様にフィルターなどを登録します。
add_filter('the_content', array($dolphinExample, 'addContent'));

?>