<?php
/*
See yak.php for information and license terms
*/

function yak_redirect_deposit($order_id, $items, $shippingcost_peritem) {
    unset($_SESSION['items']);
    
    sendConfirmationEmail($order_id);
    
    return yak_get_url(yak_get_option('yak_redirect_deposit_url', '') . '&order_id=' . $order_id);
}


function yak_redirect_cheque($order_id, $items, $shippingcost_peritem) {
    unset($_SESSION['items']);
    
    sendConfirmationEmail($order_id);
    
    return yak_get_url(yak_get_option('yak_redirect_cheque_url', '') . '&order_id=' . $order_id);   
}


function yak_redirect_paypal($order_id, $items, $shippingcost_peritem) {
	$cc = yak_get_option(PAYPAL_CURRENCY_CODE, '');
	if (isset($cc) && $cc != '') {
		$cc = '&currency_code=' . $cc;	
	}
	else {
		$cc = '';	
	}
	
    $url = yak_get_url(yak_get_option('yak_redirect_paypal_url', '') . '?cmd=_cart&upload=1&no_shipping=1&submit=PayPal' . 
			'&business=' . yak_get_option(PAYPAL_ACCOUNT, '') . $cc . 
            '&return=' . urlencode(yak_get_url(yak_get_option(PAYPAL_RETURN_URL, '')) . '&order_id=' . $order_id) . 
			'&cancel_return=' . urlencode(yak_get_url(yak_get_option(PAYPAL_CANCEL_RETURN_URL, ''))) . '&no_note=1');
    
    $count = 1;
    foreach ($items as $key => $item) {
            $itemname = urlencode(yak_get_title($item->id));
            $price = yak_calc_price($item->id);
            $shippingcost = $item->quantity * $shippingcost_peritem;
            $url = $url . '&item_name_' . $count . '=' . $itemname . '&amount_' . $count . '=' . 
                    $price . '&quantity_' . $count . '=' . $item->quantity . '&shipping_' . $count . '=' . $shippingcost; 
            
            $count += 1;
    }
    
    $url = $url . '&custom=' . $order_id;
    
    return $url;
}

function yak_paypal_ipn() {
    global $order_table, $order_log_table, $wpdb;
    
    $params = 'cmd=_notify-validate';
    $msg = '';
    foreach ( $_POST as $key => $value ) {
        $params = $params . '&' . $key . '=' . $value;
        if ($msg != '') {
            $msg = $msg . ', ';   
        }
        $msg = $msg . $key . '=' . $value;
    }
    
    $order_id = $_POST['custom'];
    $payment_gross = $_POST['mc_gross'];
	if (!isset($payment_gross) || $payment_gross == '') {
		$payment_gross = $_POST['payment_gross'];	
	}
    $business = $_POST['business'];
        
    if ($business != yak_get_option(PAYPAL_ACCOUNT, '')) {
        $wpdb->query("insert into $order_log_table values (current_timestamp(), 'business \'$business\' does not match [ $msg ]')");
        return;
    }
    
    $ch = curl_init();   
    curl_setopt($ch, CURLOPT_URL, yak_get_option('yak_redirect_paypal_url', '')); 
    curl_setopt($ch, CURLOPT_POST, 1);
    curl_setopt($ch, CURLOPT_POSTFIELDS, $params);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    $response = curl_exec($ch);
    
    if (curl_errno($ch)) {
        $wpdb->query("insert into $order_log_table values (current_timestamp(), '\'" . curl_error($ch) . "\' [ $msg ]')");
    }
    else if ($response == 'VERIFIED') {
        sendConfirmationEmail($order_id);
        
        $wpdb->query("update $order_table set funds_received = $payment_gross where id = $order_id");
        
        yak_check_order($order_id);
    }
    else {
        $wpdb->query("insert into $order_log_table values (current_timestamp(), 'paypal response not verified [ $msg ]')");
    }
    
    curl_close($ch);
   
}

function get_value($str, $tag) {
    $sub = strstr($str, $tag);

    return rtrim(substr($sub, strlen($tag), strpos($sub, '
')-strlen($tag)));    
}

function yak_paypal_pdt() {
    global $order_table, $order_log_table, $wpdb;
    
    $params = 'cmd=_notify-synch&tx=' . $_GET['tx'] . '&at=' . yak_get_option(PAYPAL_IDENTITY_TOKEN, '');
    
    syslog(LOG_INFO, "PDT url " . yak_get_option('yak_redirect_paypal_url', ''));
    syslog(LOG_INFO, "PARAMS " . $params);
    
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, yak_get_option('yak_redirect_paypal_url', '')); 
    curl_setopt($ch, CURLOPT_POST, 1);
    curl_setopt($ch, CURLOPT_POSTFIELDS, $params);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    $response = curl_exec($ch);
    
    if (curl_errno($ch)) {
        $wpdb->query("insert into $order_log_table values (current_timestamp(), '\'" . curl_error($ch) . "\' [ $msg ]')");
        
        return false;
    }
    else if (strstr($response, 'SUCCESS') == 0) {
        $payment_gross = get_value($response, 'mc_gross=');
		
        $order_id = get_value($response, 'custom=');
        
        yak_cleanup_after_order();
        
        $wpdb->query("update $order_table set funds_received = $payment_gross where id = $order_id");
        
        yak_check_order($order_id);
        
        sendConfirmationEmail($order_id);
        
        return true;
    }
    else {
        $wpdb->query("insert into $order_log_table values (current_timestamp(), 'paypal response not successful [ $response ]')");
        
        return false;
    }
    
    curl_close($ch);
}


function sendConfirmationEmail($order_id) {
    global $wpdb, $order_table, $order_detail_table;
    
    $confEmail = yak_get_option(CONFIRMATION_EMAIL_ADDRESS, '');
    if (!isset($confEmail) || $confEmail == '') {
        return;   
    }
    
    $result = $wpdb->get_row("select * from $order_table where id = $order_id");
    
    $payment_type = $result->payment_type;
    
    $split = split("\n", $result->address);
    $email = $split[1];
    
    $shipping = $result->shipping_cost;
    
    $results = $wpdb->get_results("select * from $order_detail_table where id = $order_id");
    
    $totalprice = 0;
    $totalquantity = 0;
    
    $detail = '   ' . str_pad(__('Qty', 'yak'), 6, ' ', STR_PAD_RIGHT) . '   ' .
                            str_pad(__('Title', 'yak'), 50, ' ', STR_PAD_RIGHT) .
                            str_pad(__('Price', 'yak'), 8, ' ', STR_PAD_LEFT) .
                            str_pad(__('Total', 'yak'), 8, ' ', STR_PAD_LEFT) . "\n\n";
    foreach ($results as $result) {
        $price = $result->price;
        $qty = $result->quantity;
        $totalprice += ($price * $qty);
        $itemprice = $price * $qty;
        $totalquantity += $qty;
        $detail = $detail . ' ' . sprintf('% 6d', $qty) . '   ' . str_pad($result->itemname, 50, ' ', STR_PAD_RIGHT) . sprintf('% 8d', $price) . sprintf('% 8d', $itemprice) . "\n";
    }
    
    $detail = $detail . '          ' . str_pad(__('Shipping costs', 'yak'), 58, ' ', STR_PAD_RIGHT) . sprintf('% 8d', $shipping) . "\n";
    
    $totalprice += $shipping;
    
    $confmsg = yak_get_option(CONFIRMATION_MESSAGE, '%2$s');

    $mail = sprintf($confmsg, $order_id, $detail, yak_format_money($totalprice, true), $payment_type); 

    wp_mail($email, __('Order Confirmation', 'yak'), $mail, "From: " . $confEmail);
    
    $mail = sprintf(__('The following email has been sent to %s :', 'yak'), $email) . "\r\n" . $mail;
    wp_mail($confEmail, __('Order Confirmation', 'yak'), $mail, '');
}
?>
