<?php 
/* 
Plugin Name: wp-eznavi
Plugin URI: http://wppluginsj.sourceforge.jp/wp-eznavi/
Description: au携帯電話のEZナビウォーク機能等、携帯端末の位置情報サービスで取得できる現在地マップのURLから緯度・経度情報を取得し、「<a href="http://redalt.com/wiki/Geo">Geo</a>」プラグイン互換のメタ情報としてデータベースに格納します。
Author: Sa.Ga
Version: 0.5.3
Author URI:  http://blog2.atsj.net/
Special Thanks:
	- "wp-eznavi" is named by hiromasa
		[http://hiromasa.zone.ne.jp/]. 
	- "wp-eznavi" is published by "WordPress Plugins/JSeries"
		[http://wppluginsj.sourceforge.jp/].
	- "Mac･GPS･Perl"
		[http://homepage3.nifty.com/Nowral/].
		[http://homepage3.nifty.com/Nowral/02_DATUM/02_DATUM.html]
	- "Yuriko.Net 旅行記"
		[http://www.yuriko.net/travel]
		[http://www.yuriko.net/travel/2006/08/03/197/]
*/

/*  Copyright 2006 Sa.Ga

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

$WpEznavi = new WpEznavi();
$WpEznaviAdmin = new WpEznaviAdmin();

add_action('save_post', array($WpEznavi, 'wp_eznavi'), 20);
//add_action('edit_post', array($WpEznavi, 'wp_eznavi'), 20);
add_action('publish_post', array($WpEznavi, 'wp_eznavi_pub'), 20);
add_action('admin_menu', array($WpEznaviAdmin, 'callAdminPage'));

class WpEznavi {

	/**
	 * Main Method (is publishing only)
	 * @param $postID Post-ID
	 */
	function wp_eznavi_pub($postID) {
		$this->isPublishing = true;
		$this->wp_eznavi($postID);
	}

	/**
	 * Main Method
	 * @param $postID Post-ID
	 */
	function wp_eznavi($postID) {

		global $wpdb;

		// Initializing...
		$this->createEzAnchor = get_option('wp_eznavi_allow_create_ez_anchor');
		$this->dispGpsUrl = get_option('wp_eznavi_disp_gps_url');
		$this->dispGpsUrlClass = get_option('wp_eznavi_disp_gps_url_class');
		$this->allowUpdateDefaultLatLong = (get_option('wp_eznavi_allow_update_igmp_default_latlong') == "1" ? true : false);
		$this->allowConv = (get_option('wp_eznavi_allow_conv') == "1" ? true : false);
		$this->wpEzBridge = get_option('wp_ezbridge_filename');
		$this->xmlFile = get_option('wp_eznavi_xml_filename');
		$this->topLevelNode = get_option('wp_eznavi_xml_top_level_node');
		$this->secondLevelNode = get_option('wp_eznavi_xml_second_level_node');
		$this->allowErrors = get_option('wp_eznavi_allow_errors');

		$content  =  $wpdb->get_var("SELECT post_content FROM {$wpdb->posts} " .
				"WHERE ID = '{$postID}' LIMIT 1");
		list($lat, $lon, $url, $service) = $this->getLatLongData($content);

		if ($lat != "" && $lon != "") {
			$this->updateDB($postID, $lat, $lon);

			$addATag = false;
			$createEzAnchor = intVal($this->createEzAnchor);
			if (($service == 'eznavi' && ($createEzAnchor & 1) == 1)
			|| ($service == 'imapfan' && ($createEzAnchor & 2) == 2)
			|| ($service == 'imapion' && ($createEzAnchor & 4) == 4)
			|| ($service == 'izenrin' && ($createEzAnchor & 8) == 8)) {
				$addATag = true;
			}
			$disp = intVal($this->dispGpsUrl);

			$url2 = $url;
			if ($addATag) {
				// Replace URL (Add anchor element)
				$url2 = '<a href="'. htmlspecialchars($url2) . '">' . $url2 . '</a>';
			}
			switch ($disp) {
				case 1:
				// Don't overflow URL string...
				$url2 = '<span style="width:100%;display:block;overflow:auto;">'. $url2 . '</span>';
				break;
				case 2:
				// Add custom "class" attribute on span element.
				$url2 = '<span class="'. $this->dispGpsUrlClass. '">'. $url2 . '</span>';
				break;
			}
			if ($addATag || $disp != 0) {
				$pattern = "#\b" . quotemeta($url) . "\b#";
				$newContent = preg_replace($pattern, $url2, $content);
				if (strcmp($content, $newContent) != 0) {
					$wpdb->query("UPDATE $wpdb->posts SET post_content = '" . addslashes($newContent) . 
						"' WHERE ID = '{$postID}'");
				}
			}

			$xmlFile = dirname(__FILE__) . "/". $this->xmlFile;
			if ($this->allowConv
					&& file_exists(dirname(__FILE__) . "/". $this->wpEzBridge)
					&& file_exists($xmlFile)) {
				require_once($this->wpEzBridge);
				readXML($xmlFile, $postID, $lat, $lon,
					$this->allowErrors, $this->topLevelNode, $this->secondLevelNode);
			}
		}
		return  $postID;
	}

	/**
	 * Get Latitude and Longtude
	 * @param $content The content of post
	 * @return Latitude and Longtude data (comma separated)
	 */
	function getLatLongData($content) {
		
		global  $wpdb;

		// GPS 情報 URLを探す。最初に引っかかったもののみ有効
		$url = '';
		$qs = '';
		$service = '';
		$arr = array();
		$output = array();

		// EZ ナビウォーク
		if (preg_match("#http://walk\.eznavi\.jp/map/\?(\S+)#", $content, $arr)) {
			$url     = $arr[0];
			$qs      = $arr[1];
			$service = 'eznavi';
		// iMapFan (例: http://i.mapfan.com/m.cgi?uid=NULLGWDOCOMO&F=AP&M=E139.34.4.3N35.36.50.6&SC=SY3JY8GE&AR=07900)
		} else if (preg_match("#http://i\.mapfan\.com/m\.cgi\?uid=NULLGWDOCOMO&(\S+)#", $content, $arr)) {
			$url     = $arr[0];
			$qs      = $arr[1];
			$service = 'imapfan';
		// iマピオン (例: http://i.mapion.co.jp/c/f?uc=1&nl=35/36/02.038&el=139/30/38.558&grp=mall&scl=625000&R=1&uid=NULLGWDOCOMO)
		} else if (preg_match("#http://i\.mapion\.co\.jp/c/f\?(\S+)#", $content, $arr)) {
			$url     = $arr[0];
			$qs      = $arr[1];
			$service = 'imapion';
		// ゼンリン (例: http://i.i.zenrin.co.jp/MapToLink/p1?scd=00300&rl=%2fzi%2fmenu%2far1%3farea%3d07900&x=6&n=35.616297&e=139.565364&uid=NULLGWDOCOMO)
		} else if (preg_match("#http://i\.i\.zenrin\.co\.jp/MapToLink/p1\?(\S+)#", $content, $arr)) {
			$url     = $arr[0];
			$qs      = $arr[1];
			$service = 'izenrin';
		}

		if ($url == "" || $qs == "") {
			// 緯度・経度情報が含まれるURLを取得できなければ退場。
			return array("", "", "", "");
		}
		// 文字列を無害化
		$qs = str_replace("&amp;", "&", $qs);
		$qs = urldecode($qs);
		// 「key=value」のペアを全部取得
		$datum = "";
		$unit = "";
		$lat = "";
		$lon = "";
		// 取得したペアから、必要な情報を取得
		parse_str($qs, $output);
		foreach ($output as $key => $value) {
			$value = trim($value);
			switch ($key) {
			// EZ navi
			case "datum":
				$datum = $value;
				break;
			case "unit":
				$unit = $value;
				break;
			case "lat":
				$lat = $value;
				break;
			case "lon":
				$lon = $value;
				break;
			case "fm":
				$fm = $value;
				break;
			// iMapFan
			case "M":
				preg_match('/^E([.0-9]+)N([.0-9]+)$/', $value, $arr);
				$lon = $arr[1];
				$lat = $arr[2];
				break;
			// Mapion
			case "nl":
				$lat = str_replace('/', '.', $value);
				break;
			case "el":
				$lon = str_replace('/', '.', $value);
				break;
			// Zenrin
			case "n":
				$lat = floatval($value);
				break;
			case "e":
				$lon = floatval($value);
				break;
			}
		}

		// 百分率表記に変換
		$n = $this->dms2percent($lat, 90);
		$e = $this->dms2percent($lon, 180);
		// 測地系の取得と変換
		if ($datum == "1" || $service == 'imapfan' || $service == 'imapion' || $service == 'izenrin') {
			// 1:日本測地系
			// GoogleMapとEZナビで誤差が生じているので修正（測地系の違い）。
			// オープンiエリアは日本測地系なので全部修正。
			list($n, $e) = $this->convLatLng($n, $e);
		} else {
			// 0:世界測地系
		}
		return array ($n, $e, $url, $service);
	}

	/**
	 * Insert or Update Latitude and Longtude data to your wordpress database.
	 * @param $postID Post-ID
	 * @param $lat Latitude data
	 * @param $lon Longtude data
	 */
	function updateDB($postID, $lat, $lon) {

		global  $wpdb;

		$cnt = $wpdb->get_var("SELECT Count(*) FROM {$wpdb->postmeta} " .
				"WHERE post_id = '{$postID}' AND meta_key = '_geo_location' ");
		if ($cnt == null || $cnt == '0') {
			add_post_meta($postID, '_geo_location', $lat . "," . $lon);
		} else {
			$meta_value = $wpdb->get_var("SELECT meta_value FROM {$wpdb->postmeta} " .
					"WHERE post_id = '{$postID}' AND meta_key = '_geo_location' LIMIT 1 ");
			if ($meta_value == '' || $meta_value == ',') {
				update_post_meta($postID, '_geo_location',  $lat . "," . $lon, $meta_value);
			}
		}

		if ($this->isPublishing && $this->allowUpdateDefaultLatLong) {
			// Update "Instant Googlemap Plugin" default latitude/longtitude ...
			$yf_default_latitude = get_option('yf_default_latitude');
			if ($yf_default_latitude) {
				update_option('yf_default_latitude', $lat);
			}
			$yf_default_longitude = get_option('yf_default_longitude');
			if ($yf_default_longitude) {
				update_option('yf_default_longitude', $lon);
			}
		}
	}
	
	/**
	 * Convert Deg.Min.Sec to percentage
	 * @param $str Latitude/Longtitude string
	 * @param $range Absolute value of Latitude/Longtitude limit
	 * @return Percentage value
	 */
	function dms2percent($str, $limit) {
		$item = array();
		$value = '';
		if (preg_match("#([-+]?)(\d+)\.(\d+)\.(\d+)\.(\d+)#", $str, $item)) {
			$value = ($item[1] == '-' ? -1 : 1) *
				 (intval($item[2]) + 
				  intval($item[3]) / 60 + 
				  intval($item[4]) / 3600 + 
				  intval($item[5]) / 360000);
		} elseif (is_numeric($str)) {
			$value = floatval($str);
		}
		if ($value < -1 * $limit || $value > $limit) {
			$value = '';
		}
		return $value;
	}

	/**
	 * Convert Geodetic Data (TK -> WGS)
	 * @param $lat Latitude (TK; double float)
	 * @param $lng Longtude (TK; double float)
	 * @return Latitude and Longtude data (WGS; comma separated)
	 */
	function convLatLng($lat, $lng) {

		/*
		 * Thanks to "Mac･GPS･Perl"
		 * [http://homepage3.nifty.com/Nowral/].
		 * [http://homepage3.nifty.com/Nowral/02_DATUM/02_DATUM.html]
		 */
	
		// 「高さ」の取得が不可能なので簡便法で・・・。
		$n = $lat - 0.00010695*$lat + 0.000017464*$lng + 0.0046017;
		$e = $lng - 0.000046038*$lat - 0.000083043*$lng + 0.010040;
		return array($n, $e);
	}
}

class WpEznaviAdmin {

	/**
	 * Call the Administration page of "wp-eznavi".
	 */
	function callAdminPage() {

	    if (function_exists('add_options_page')) {
			add_options_page('wp-eznavi', 'wp-eznavi', 10,
			basename(__FILE__), array($this, 'adminPage'));
	    }
	}

	/**
	 * Administration page of "wp-eznavi".
	 */
	function adminPage() {

		if (!get_option('wp_eznavi_allow_update_igmp_default_latlong')) {
			// Init options
			$this->initOptions(true);
		} else if (isset($_POST['info_init'])) {
			// Init options
			$this->initOptions(false);
		} else if (isset($_POST['info_update'])) {
			// Update options
			$this->updateOptions();
		}
?>

<script type="text/javascript">
<!--
var viewSettings = new Array();
// -->
</script>

<div class="wrap">
<form method="post" action="#">

<h2><?php _e('Options for &quot;wp-eznavi&quot;') ?></h2>

<h3><?php _e('<abbr title="Uniform Resource Locator">URL</abbr>とリンクに関する設定') ?>
<span id="virtualToggle_anchor_setting"></span></h3>

<div id="anchor_setting">

	<p>
	<?php _e("GPS情報URLに関する各種設定をおこないます。") ?><br />
	<?php _e("これらの設定は、1回の投稿ごとに最初のGPS情報URLに対してのみ有効です。") ?>
	</p>
	
	<?php
		// アンカータグを設定するか否か
		$createEzAnchor = intVal(get_option('wp_eznavi_allow_create_ez_anchor'));
	?>
	<fieldset>
	<legend>
	<?php _e("リンクするGPS情報URL") ?>
	</legend>

	<p>
	<?php _e("投稿内容に下記のGPS情報URLが含まれるときに、指定されたページにリンクするか否かの設定をおこないます。") ?>
	</p>
	
	<div>
		<input type="checkbox" name="createEzAnchor[]" id="createEzAnchor_1" value="1"
		<?php 
			if (($createEzAnchor & 1) == 1) {
				echo ' checked="checked"';
			}
		?>
		/>
		<label for="createEzAnchor_1"><?php _e("EZナビウォーク") ?>
		<em><?php _e("（PC、au携帯電話で利用可能）") ?></em></label>
	</div>
	<div>
		<input type="checkbox" name="createEzAnchor[]" id="createEzAnchor_2" value="2"
		<?php 
			if (($createEzAnchor & 2) == 2) {
				echo ' checked="checked"';
			}
		?>
		/>
		<label for="createEzAnchor_2"><?php _e("iMapFan") ?>
		<em><?php _e("（iモード対応端末で利用可能）") ?></em></label>
	</div>
	<div>
		<input type="checkbox" name="createEzAnchor[]" id="createEzAnchor_4" value="4"
		<?php 
			if (($createEzAnchor & 4) == 4) {
				echo ' checked="checked"';
			}
		?>
		/>
		<label for="createEzAnchor_4"><?php _e("iマピオン") ?>
		<em><?php _e("（iモード対応端末で利用可能）") ?></em></label>
	</div>
	<div>
		<input type="checkbox" name="createEzAnchor[]" id="createEzAnchor_8" value="8"
		<?php 
			if (($createEzAnchor & 8) == 8) {
				echo ' checked="checked"';
			}
		?>
		/>
		<label for="createEzAnchor_8"><?php _e("ゼンリン") ?>
		<em><?php _e("（iモード対応端末で利用可能）") ?></em></label>
	</div>

	<dl>
	<dt><?php _e("ご注意") ?>
	<span id="virtualToggle_anchor_notice"></span></dt>
	<dd id="anchor_notice">
	<?php _e("リンク先のページをご利用になるには、各ページに対応する端末が必要です。") ?><br />
	<?php _e("特に、iエリアの各サービスは、PCからはご利用いただけませんのでご注意ください。") ?><br />
	</dd>
	</dl>

	</fieldset>

	<?php
		// GPS情報の表示方法
		$dispGpsUrl = get_option('wp_eznavi_disp_gps_url');
		$dispGpsUrlClass = get_option('wp_eznavi_disp_gps_url_class');
	?>
	<fieldset>
	<legend>
	<?php _e("GPS情報URLの表示方法") ?>
	</legend>

	<p>
	<?php _e("GPS情報URLが長いときの表示方法に関する設定をおこないます。") ?>
	</p>
	
	<div>
		<input type="radio" name="dispGpsUrl" id="dispGpsUrl_0" value="0x00000000"
		onchange="changeEnableFieldset(!this.checked, 'dispGpsUrl_2_class');"
		<?php 
			if ($dispGpsUrl == '0x00000000') {
				echo ' checked="checked"';
			}
		?>
		/>
		<label for="dispGpsUrl_0"><?php _e("ブラウザの通常の方法") ?>
		<em><?php _e("（URLが長い場合、横にはみ出すことがあります）") ?></em></label>
	</div>
	<div>
		<input type="radio" name="dispGpsUrl" id="dispGpsUrl_1" value="1"
		onchange="changeEnableFieldset(!this.checked, 'dispGpsUrl_2_class');"
		<?php 
			if ($dispGpsUrl == '1') {
				echo ' checked="checked"';
			}
		?>
		/>
		<label for="dispGpsUrl_1"><?php _e("画面内でURLをスクロールさせる") ?>
		<em><?php _e("（要スタイルシート。見た目は悪くなりますが、URLが投稿記事本文からはみ出ません）") ?></em></label>
	</div>
	<div>
		<input type="radio" name="dispGpsUrl" id="dispGpsUrl_2" value="2"
		onchange="changeEnableFieldset(this.checked, 'dispGpsUrl_2_class');"
		<?php 
			if ($dispGpsUrl == '2') {
				echo ' checked="checked"';
			}
		?>
		/>
		<label for="dispGpsUrl_2"><?php _e("URLにスタイルシートのクラスを適用する") ?>
		<em><?php _e("（上級者向け。要スタイルシート。テーマ・テンプレートのCSSファイルを御自身でカスタマイズすることで、任意のスタイルをGPS情報URLに適用させることができます）") ?></em></label>
		<ul>
		<li><label for="dispGpsUrl_2_class"><?php _e("付加するCSSのクラス名") ?></label>
		<input type="text" name="dispGpsUrlClass" id="dispGpsUrl_2_class" value="<?php echo $dispGpsUrlClass ?>" maxlength="32" size="32" /></li>
		</ul>
	</div>

	<dl>
	<dt><?php _e("ご注意") ?>
	<span id="virtualToggle_dispGpsUrl_notice"></span></dt>
	<dd id="dispGpsUrl_notice">
	<?php _e("表示方法をいずれに設定した場合でも、設定した内容が直接投稿内容に書き込まれます。") ?><br />
	<?php _e("そのため、記事投稿後に表示方法を変更しても、変更前に投稿した記事の内容は変化しません。") ?><br />
	</dd>
	</dl>

	</fieldset>

</div>

<h3><?php _e("緯度・経度記録設定") ?><span id="virtualToggle_metadata_setting"></span></h3>

<div id="metadata_setting">

	<p>
	<?php _e("緯度・経度情報の記録に関する設定をおこないます。") ?>
	</p>
	
	<?php
		// 記事公開時に"Instant Googlemap Plugin"表示初期位置を書き換えるか否か
		$allowUpdateDefaultLatLong = get_option('wp_eznavi_allow_update_igmp_default_latlong');
	?>
	<fieldset>
	<legend>
	<?php _e('「<a href="http://www.pingmag.jp/2006/02/06/the-instant-googlemap-plugin/">Instant Googlemap Plugin</a>」に関する設定') ?>
	</legend>
	<div>
		<input type="checkbox" name="allowUpdateDefaultLatLong" id="allowUpdateDefaultLatLong" value="1"
		<?php 
			if ($allowUpdateDefaultLatLong == "1") {
				echo ' checked="checked"';
			}
		?>
		/>
		<label for="allowUpdateDefaultLatLong"><?php _e("記事公開時に、取得したGPS情報で表示初期位置を上書きする。") ?></label>
	</div>
	</fieldset>

	<dl>
	<dt><?php _e("ご注意") ?>
	<span id="virtualToggle_metadata_notice"></span></dt>
	<dd id="metadata_notice">
	<?php _e("当該プラグインがインストールされていない場合でも設定は可能ですが、無意味です。") ?><br />
	</dd>
	</dl>

</div>

<h3><?php _e('<abbr title="Extensible Markup Language">XML</abbr>情報取得設定') ?><span id="virtualToggle_xml_setting"></span></h3>

<div id="xml_setting">

	<p><?php _e("XMLファイルを読み込み、緯度・経度を元にXMLファイル内の情報を取得するか否かの設定をおこないます。") ?></p>

	<p>
		<?php
			// XMLファイルを読み込み、緯度・経度→コード変換機能を有効にするか否か
			$allowConv = get_option('wp_eznavi_allow_conv');
		?>
		<input type="checkbox" name="allowConv" id="allowConv" value="1"
		onchange="changeEnableFieldset(this.checked, 'fieldset_xml_sub_setting');"
		<?php 
			if ($allowConv == "1") {
				echo ' checked="checked"';
			}
		?>
		/>
		<label for="allowConv"><?php _e("XML情報を取得する。") ?></label>
	</p>

	<fieldset id="fieldset_xml_sub_setting">
	<legend>
	<?php _e("XML読み込みに関する設定") ?>
	</legend>

	<dl>
	<?php
			// 緯度・経度→コード変換モジュールのファイル名
			$wpEzBridge = get_option('wp_ezbridge_filename');
	?>
	<dt><label for="wpEzBridge"><?php _e("情報取得モジュールのファイル名") ?></label></dt>
	<dd>
		<input type="text" name="wpEzBridge" id="wpEzBridge" value="<?php echo $wpEzBridge ?>" size="32" maxlength="128" />
		<?php _e("（通常は初期状態のままお使いください）") ?>
	</dd>
	
	<?php
			// XMLファイルの名前
			$xmlFile = get_option('wp_eznavi_xml_filename');
	?>
	<dt><label for="xmlFile"><?php _e("地域情報を記載したXMLファイル名") ?></label></dt>
	<dd>
		<input type="text" name="xmlFile" id="xmlFile" value="<?php echo $xmlFile ?>" size="32" maxlength="128" />
		<?php _e("（通常は初期状態のままお使いください）") ?>
	</dd>
	
	<?php
			// XMLファイルのトップレヴェル・ノード名称
			$topLevelNode = get_option('wp_eznavi_xml_top_level_node');
	?>
	<dt><label for="xmlTopLevelNode"><?php _e("XMLファイルのトップレベル・ノード名称") ?></label></dt>
	<dd>
		<input type="text" name="xmlTopLevelNode" id="xmlTopLevelNode" value="<?php echo $topLevelNode ?>" size="16" maxlength="128" />
		<?php _e("（通常は初期状態のままお使いください）") ?>
	</dd>
	
	<?php
			// XMLファイルの2レヴェル目のノード名称。データの単位を表現する。
			$secondLevelNode = get_option('wp_eznavi_xml_second_level_node');
	?>
	<dt><label for="xmlSecondLevelNode"><?php _e("XMLファイルのデータ単位を表現するノードの名称") ?></label></dt>
	<dd>
		<input type="text" name="xmlSecondLevelNode" id="xmlSecondLevelNode" value="<?php echo $secondLevelNode ?>" size="16" maxlength="128" />
		<?php _e("（通常は初期状態のままお使いください）") ?>
	</dd>
	</dl>

	<dl>
	<dt><?php _e("ご注意") ?>
	<span id="virtualToggle_xml_notice"></span></dt>
	<dd id="xml_notice">
	<?php _e("「wp-eznavo」フルパッケージ版に同梱されている「<code>wp-ezbridge.php</code>」および「<code>ezarea.xml</code>」をお使いの場合、上記設定を変更する必要はありません。") ?><br />
	</dd>
	</dl>

	<dl>
	<?php
			// 現在地と緯度および経度が±$allowErrors度の範囲内にあるもののみを計算対象とする。
			$allowErrors = get_option('wp_eznavi_allow_errors');
	?>
	<dt><label for="allowErrors"><?php _e("取得したGPS情報からの最寄りの拠点情報を取得するための計算範囲") ?></label></dt>
	<dd>
		<input type="text" name="allowErrors" id="allowErrors" value="<?php echo $allowErrors ?>" size="8" maxlength="10" style="text-align:right;" />
		<?php _e("度") ?>
		<?php _e("（数値）") ?>
	</dd>
	</dl>

	<dl>
	<dt><?php _e("ご注意") ?>
	<span id="virtualToggle_xml2_notice"></span></dt>
	<dd id="xml2_notice">
	<?php _e("GPS情報に対し、東西南北の誤差がここで指定した数値の範囲内にある情報のみを計算対象とします。") ?><br />
	<?php _e("たとえば、設定値が「1.0」で、GPS情報が北緯35.5度、東経139.5度の場合、") ?>
	<?php _e("北緯34.5度～36.5度、東経138.5度～140.5度の範囲で拠点を検索します。") ?><br />
	<?php _e("通常は、初期値の1.0で問題ないと思われます。") ?><br />
	</dd>
	</dl>

	</fieldset>

</div>

<div class="submit">
<p>
<input type="submit" name="info_update" value="<?php _e('設定を更新する') ?> &raquo;" />
</p>
</div>
</form>
</div>

<div class="wrap">
<form method="post" action="#">

<h2><?php _e('Initialize') ?><span id="virtualToggle_initialize_setting"></span></h2>

<div id="initialize_setting">

<p>
<?php _e('このボタンを押下すると、設定を初期状態に戻すことが出来ます。') ?>
</p>
<p>
<?php _e('初期化すると、現在の設定には戻せません。') ?>
</p>

<div class="submit">
<p>
<input type="submit" name="info_init" value="<?php _e('設定を初期化する') ?> &raquo;" onclick="return askInit();" />
</p>
</div>
</div>

</form>
</div>

<script type="text/javascript">
<!--
function askInit() {
	var msg = "<?php _e('「wp-eznavi」の設定を初期化しようとしています。') ?>\n";
	msg += "<?php _e('初期化すると、現在の設定には戻せません。') ?>\n";
	msg += "<?php _e('実行しますか？') ?>";
	return confirm(msg);
}

function changeEnableFieldset(isChecked, fieldsetID) {
	document.getElementById(fieldsetID).disabled = !isChecked;
}

function changeView(divID, toShow) {

	var virtualToggle = '&nbsp;[<a href="javascript:changeView(\'' + divID + '\', !viewSettings[\'' + divID + '\'])">';

	viewSettings[divID] = toShow;
	if (toShow) {
		virtualToggle += '-';
		document.getElementById(divID).style.display = 'block';
	} else {
		virtualToggle += '+';
		document.getElementById(divID).style.display = 'none';
	}
	virtualToggle += '</a>]';
	document.getElementById("virtualToggle_" + divID).innerHTML = virtualToggle;
}

// Initializing
changeView("xml_setting", false);
changeView("metadata_setting", false);
changeView("anchor_setting", false);
changeView("initialize_setting", false);
changeView("anchor_notice", false);
changeView("metadata_notice", false);
changeView("xml_notice", false);
changeView("xml2_notice", false);
changeView("dispGpsUrl_notice", false);

changeEnableFieldset(document.getElementById("allowConv").checked, "fieldset_xml_sub_setting");
changeEnableFieldset(document.getElementById("dispGpsUrl_2").checked, "dispGpsUrl_2_class");
// -->
</script>

<?php
	}

	/**
	 * Initialize all options...
	 * @param $isFirstRun
	 */
	function initOptions($isFirstRun = false) {

		// アンカータグを設定するか否か
		delete_option('wp_eznavi_allow_create_ez_anchor');
		add_option('wp_eznavi_allow_create_ez_anchor', '1');

		// GPS情報の表示方法
		delete_option('wp_eznavi_disp_gps_url');
		add_option('wp_eznavi_disp_gps_url', '0');

		// GPS情報の付加class
		delete_option('wp_eznavi_disp_gps_url_class');
		add_option('wp_eznavi_disp_gps_url_class', 'wpezGpsUrl');

		// 記事公開時に"Instant Googlemap Plugin"表示初期位置を書き換えるか否か
		delete_option('wp_eznavi_allow_update_igmp_default_latlong');
		add_option('wp_eznavi_allow_update_igmp_default_latlong', '1');

		// XMLファイルを読み込み、緯度・経度→コード変換機能を有効にするか否か
		delete_option('wp_eznavi_allow_conv');
		add_option('wp_eznavi_allow_conv', '1');

		// 緯度・経度→コード変換モジュールのファイル名
		delete_option('wp_ezbridge_filename');
		add_option('wp_ezbridge_filename', 'wp-ezbridge.php');

		// XMLファイルの名前
		delete_option('wp_eznavi_xml_filename');
		add_option('wp_eznavi_xml_filename', 'ezarea.xml');

		// XMLファイルのトップレヴェル・ノード名称
		delete_option('wp_eznavi_xml_top_level_node');
		add_option('wp_eznavi_xml_top_level_node', 'ezarea');

		// XMLファイルの2レヴェル目のノード名称。データの単位を表現する。
		delete_option('wp_eznavi_xml_second_level_node');
		add_option('wp_eznavi_xml_second_level_node', 'area');

		// 現在地と緯度および経度が±$allowErrors度の範囲内にあるもののみを計算対象とする。
		delete_option('wp_eznavi_allow_errors');
		add_option('wp_eznavi_allow_errors', '1.0');

		if ($isFirstRun) {
?>
<div class="updated">
<p>
<?php _e("「wp-eznavi」をインストールしていただき、ありがとうございます。");?><br />
<?php _e("初期設定が完了いたしましたので、どうぞご利用ください。");?>
</p>
</div>
<?php
		} else {
?>
<div class="updated">
<p><strong><?php _e("設定を初期化しました。");?></strong></p>
</div>
<?php
		}
	}

	/**
	 * Update options...
	 */	
	function updateOptions() {

		// Validation Check...
		$msgs = array();

		$dispGpsUrl = $_POST['dispGpsUrl'];
		if ($dispGpsUrl == 2) {
			$useCustomStyleClass = $_POST['dispGpsUrlClass'];
			if ($useCustomStyleClass == '') {
				$msgs[] = __("「")
				. __("CSSのクラス名")
				. __("」")
				. __("が指定されていません。");
			}
		}

		$allowConv = $_POST['allowConv'];
		if ($allowConv) {
			$wpEzBridge = $_POST['wpEzBridge'];
			if ($wpEzBridge == '') {
				$msgs[] = __("「")
				. __("情報取得モジュールのファイル名")
				. __("」")
				. __("が指定されていません。");
			}
			$xmlFile = $_POST['xmlFile'];
			if ($xmlFile == '') {
				$msgs[] = __("「")
				. __("地域情報を記載したXMLファイル名")
				. __("」")
				. __("が指定されていません。");
			}
			$topLevelNode = $_POST['xmlTopLevelNode'];
			if ($topLevelNode == '') {
				$msgs[] = __("「")
				. __("XMLファイルのトップレベル・ノード名称")
				. __("」")
				. __("が指定されていません。");
			}
			$secondLevelNode = $_POST['xmlSecondLevelNode'];
			if ($secondLevelNode == '') {
				$msgs[] = __("「")
				. __("XMLファイルのデータ単位を表現するノードの名称")
				. __("」")
				. __("が指定されていません。");
			}
			$allowErrors = $_POST['allowErrors'];
			if ($allowErrors == '') {
				$msgs[] = __("「")
				. __("取得したGPS情報からの最寄りの拠点情報を取得するための計算範囲")
				. __("」")
				. __("が指定されていません。");
			} else if (!preg_match('/^\d+(\.\d+)?$/', $allowErrors)) {
				$msgs[] = __("「")
				. __("取得したGPS情報からの最寄りの拠点情報を取得するための計算範囲")
				. __("」")
				. __("には、数値を指定してください。")
				. __("（")
				. __("指定された値")
				. __("：")
				. $allowErrors
				. __("）");
			} else if (floatVal($allowErrors) <= 0) {
				$msgs[] = __("「")
				. __("取得したGPS情報からの最寄りの拠点情報を取得するための計算範囲")
				. __("」")
				. __("には、0より大きい数値を指定してください。")
				. __("（")
				. __("指定された値")
				. __("：")
				. $allowErrors
				. __("）");
			}
		}

		if (count($msgs) > 0) {
?>
<div class="error">
<p><?php _e("エラーが発生しました。") ?></p>
<ul>
<?php
			foreach ($msgs as $msg) {
				echo "<li>". $msg. "</li>";
			}
?>
</ul>
</div>
<?php
			return;
		}

		// Update Database
		// アンカータグを設定するか否か
		$createEzAnchors = $_POST['createEzAnchor'];
		$createEzAnchor = 0;
		if ($createEzAnchors) {
			foreach ($createEzAnchors as $ezAnchor) {
				$createEzAnchor += intVal($ezAnchor);
			}
		}
		if ($createEzAnchor) {
			update_option('wp_eznavi_allow_create_ez_anchor', $createEzAnchor);
		} else {
//			add_option('wp_eznavi_allow_create_ez_anchor', $createEzAnchor);
			update_option('wp_eznavi_allow_create_ez_anchor', '0');
		}

		// GPS情報の表示方法
		$dispGpsUrl = $_POST['dispGpsUrl'];
		if ($dispGpsUrl) {
			update_option('wp_eznavi_disp_gps_url', $dispGpsUrl);
		} else {
			add_option('wp_eznavi_disp_gps_url', $dispGpsUrl);
		}

		// GPS情報の付加class
		$dispGpsUrlClass = $_POST['dispGpsUrlClass'];
		if ($dispGpsUrlClass) {
			update_option('wp_eznavi_disp_gps_url_class', $dispGpsUrlClass);
		} else {
			add_option('wp_eznavi_disp_gps_url_class', $dispGpsUrlClass);
		}

		// 記事公開時に"Instant Googlemap Plugin"表示初期位置を書き換えるか否か
		$allowUpdateDefaultLatLong = $_POST['allowUpdateDefaultLatLong'];
		if ($allowUpdateDefaultLatLong) {
			update_option(
				'wp_eznavi_allow_update_igmp_default_latlong',
				$allowUpdateDefaultLatLong);
		} else {
//			add_option(
//				'wp_eznavi_allow_update_igmp_default_latlong',
//				$allowUpdateDefaultLatLong);
			update_option(
				'wp_eznavi_allow_update_igmp_default_latlong', '0x00000000');
		}

		// XMLファイルを読み込み、緯度・経度→コード変換機能を有効にするか否か
		$allowConv = $_POST['allowConv'];
		if ($allowConv) {
			update_option('wp_eznavi_allow_conv', $allowConv);
		} else {
//			add_option('wp_eznavi_allow_conv', $allowConv);
			update_option('wp_eznavi_allow_conv', '0x00000000');
		}
		// 緯度・経度→コード変換モジュールのファイル名
		$wpEzBridge = $_POST['wpEzBridge'];
		if ($wpEzBridge) {
			update_option('wp_ezbridge_filename', htmlspecialchars($wpEzBridge));
		} else {
			add_option('wp_ezbridge_filename', htmlspecialchars($wpEzBridge));
		}
		// XMLファイルの名前
		$xmlFile = $_POST['xmlFile'];
		if ($xmlFile) {
			update_option('wp_eznavi_xml_filename', htmlspecialchars($xmlFile));
		} else {
			add_option('wp_eznavi_xml_filename', htmlspecialchars($xmlFile));
		}
		// XMLファイルのトップレヴェル・ノード名称
		$topLevelNode = $_POST['xmlTopLevelNode'];
		if ($topLevelNode) {
			update_option('wp_eznavi_xml_top_level_node', htmlspecialchars($topLevelNode));
		} else {
			add_option('wp_eznavi_xml_top_level_node', htmlspecialchars($topLevelNode));
		}
		// XMLファイルの2レヴェル目のノード名称。データの単位を表現する。
		$secondLevelNode = $_POST['xmlSecondLevelNode'];
		if ($secondLevelNode) {
			update_option('wp_eznavi_xml_second_level_node', htmlspecialchars($secondLevelNode));
		} else {
			add_option('wp_eznavi_xml_second_level_node', htmlspecialchars($secondLevelNode));
		}
		// 現在地と緯度および経度が±$allowErrors度の範囲内にあるもののみを計算対象とする。
		$allowErrors = $_POST['allowErrors'];
		if ($allowErrors) {
			update_option('wp_eznavi_allow_errors', htmlspecialchars($allowErrors));
		} else {
			add_option('wp_eznavi_allow_errors', htmlspecialchars($allowErrors));
		}

?>
<div class="updated">
<p><strong><?php _e("設定を更新しました。");?></strong></p>
</div>
<?php
	}
}

?>
